import { expect, test, describe, it } from 'vitest';
import type { GraphQueryResultMetaFromBackend } from 'ts-common';
import { hashDictionary, hashIsEqual } from '../../utils/hashing';
import { compareHashedQueryResults } from './../../readers/diffCheck';
import { Logger } from 'ts-common';

Logger.excludedOwners.push('ts-common');
Logger.excludedOwners.push('query-service');

describe('Hash Comparison Tests', () => {
  it('should detect different hashes for different graph structures', () => {
    // First query result
    const query1: GraphQueryResultMetaFromBackend = {
      nodes: [{ _id: 'node1' }, { _id: 'node2' }],
      edges: [{ _id: 'edge1' }],
    } as GraphQueryResultMetaFromBackend;

    // Second query result with different structure
    const query2: GraphQueryResultMetaFromBackend = {
      nodes: [{ _id: 'node1' }, { _id: 'node2' }, { _id: 'node3' }],
      edges: [{ _id: 'edge1' }, { _id: 'edge2' }],
    } as GraphQueryResultMetaFromBackend;

    const hash1 = hashDictionary({
      nodes: query1.nodes.map(node => node._id),
      edges: query1.edges.map(edge => edge._id),
    });

    const hash2 = hashDictionary({
      nodes: query2.nodes.map(node => node._id),
      edges: query2.edges.map(edge => edge._id),
    });

    // Test direct hash comparison
    expect(hashIsEqual(hash1, hash2)).toBe(false);

    // Test using compareHashedQueryResults
    expect(compareHashedQueryResults(hash1, hash2)).toBe(true);
  });

  it('should detect identical hashes for same graph structures', () => {
    const query1 = {
      nodes: [{ _id: 'node1' }, { _id: 'node2' }],
      edges: [{ _id: 'edge1' }],
    } as GraphQueryResultMetaFromBackend;

    const query2 = {
      nodes: [{ _id: 'node1' }, { _id: 'node2' }],
      edges: [{ _id: 'edge1' }],
    } as GraphQueryResultMetaFromBackend;

    const hash1 = hashDictionary({
      nodes: query1.nodes.map(node => node._id),
      edges: query1.edges.map(edge => edge._id),
    });

    const hash2 = hashDictionary({
      nodes: query2.nodes.map(node => node._id),
      edges: query2.edges.map(edge => edge._id),
    });

    // Test direct hash comparison
    expect(hashIsEqual(hash1, hash2)).toBe(true);

    // Test using compareHashedQueryResults
    expect(compareHashedQueryResults(hash1, hash2)).toBe(false);
  });
});
