import { expect, test, describe, it } from 'vitest';
import { populateTemplate } from './../../utils/insights';
import { type GraphQueryResultMetaFromBackend } from 'ts-common';
import { Logger } from 'ts-common';

Logger.excludedOwners.push('ts-common');
Logger.excludedOwners.push('query-service');

const mockResult: GraphQueryResultMetaFromBackend = {
  metaData: {
    topological: {
      density: 0,
      self_loops: 0,
    },
    nodes: {
      count: 1,
      labels: ['NodeTypeA'],
      types: {
        NodeTypeA: {
          count: 1,
          attributes: {
            age: {
              attributeType: 'number',
              statistics: {
                min: 10,
                max: 50,
                average: 42,
                count: 100,
              },
            },
          },
        },
      },
    },
    edges: {
      count: 0,
      labels: [],
      types: {},
    },
  },
  nodeCounts: { updatedAt: 2313 },
  nodes: [],
  edges: [],
};

describe('populateTemplate', () => {
  it('should replace statistic variables correctly', async () => {
    const template = 'The mean value is {{ statistic:NodeTypeA • age • average }}.';
    const expectedOutput = 'The mean value is 42 .';
    const result = await populateTemplate(template, mockResult, []);

    expect(result).toBe(expectedOutput);
  });

  it('should replace visualization variables correctly', async () => {
    const template = 'The mean value is {{ statistic:NodeTypeA • age • average }}.';
    const expectedOutput = 'The mean value is 42 .';
    const result = await populateTemplate(template, mockResult, []);

    expect(result).toBe(expectedOutput);
  });

  it('should handle wrong input parameters', async () => {
    const template = '';
    const expectedOutput = 'Html no valid';
    const result = await populateTemplate(template, mockResult, []);

    expect(result).toBe(expectedOutput);
  });
});
