import { type InsightModel, isValidEmail, isValidCronExpression } from 'ts-common';
import { log } from '../../logger';

export function validateInsight(insight: InsightModel, force: boolean) {
  if (!insight || insight.userId == null || !insight.template || !insight.userId || !insight.saveStateId) {
    log.error('Invalid Insight received in insightProcessorConsumer:', insight);
    return false;
  }

  if (!insight.recipients || insight.recipients.length === 0) {
    log.error('No recipients found in the insight, skipping');
    return false;
  }

  for (const recipient of insight.recipients) {
    if (!isValidEmail(recipient)) {
      log.error(`Invalid email for recipient: ${recipient}`);
      return false;
    }
  }

  if (!insight.frequency || !isValidCronExpression(insight.frequency)) {
    log.error('No frequency found in the insight, skipping');
    return false;
  }

  return true;
}
