import { type InsightModel } from 'ts-common';
import { log } from '../../logger';

export function validateTypeInsight(insight: InsightModel, force: boolean) {
  switch (insight.alarmMode) {
    case 'disabled':
      if (!force) {
        log.debug('Alarm mode is disabled', insight.id);
        return false;
      } else {
        return true;
      }

    case 'conditional':
      if (!insight.conditionsCheck || insight.conditionsCheck.length === 0) {
        log.error('No conditions found in Insight conditionsCheck');
        return false;
      }
      for (const condition of insight.conditionsCheck) {
        // TODO! remove property from insight conditional model
        if (!condition.nodeLabel || !condition.statistic || !condition.operator || condition.value === undefined) {
          log.error('Invalid condition found:', condition);
          return false;
        }
      }
      return true;

    case 'diff':
      if (!insight.frequency) {
        log.error('No frequency found in Insight frequency: ', insight.frequency);
        return true;
      } else {
        return true;
      }
    case 'always':
      if (!insight.frequency) {
        log.error('No frequency found in Insight frequency: ', insight.frequency);
        return false;
      } else {
        return true;
      }

    default:
      return true;
  }
}
